==> nextcloud-app-deck-1%3A1.14.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/es_CO.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "%s on %s" : "%s en %s",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "copy" : "Copiar",
    "Done" : "Terminado",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Cancel" : "Cancelar",
    "File already exists" : "El archivo ya existe",
    "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
    "Add card" : "Agregar tarjeta",
    "Completed" : "Completado",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Activity" : "Actividad",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Owner" : "Dueño",
    "Delete" : "Borrar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Download" : "Descargar",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Created:" : "Creado:",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "Remove due date" : "Eliminar fecha de expiración",
    "(group)" : "(grupo)",
    "seconds ago" : "hace segundos",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Keyboard shortcut" : "Atajo del teclado",
    "Action" : "Acción",
    "Search" : "Buscar",
    "Archived boards" : "Tableros archivados",
    "Shared with you" : "Compartido con usted",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar el tablero",
    "Unarchive board" : "Desarchivar tablero",
    "Archive board" : "Archivar tablero",
    "No notifications" : "No hay notificaciones",
    "Delete board" : "Borrar tableros",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "Close" : "Cerrar",
    "Share" : "Compartir"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-deck-1%3A1.15.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/es_CO.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "%s on %s" : "%s en %s",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "copy" : "Copiar",
    "Done" : "Terminado",
    "File" : "Archivo",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Cancel" : "Cancelar",
    "File already exists" : "El archivo ya existe",
    "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
    "Add card" : "Agregar tarjeta",
    "Completed" : "Completado",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Activity" : "Actividad",
    "Undo" : "Deshacer",
    "Transfer" : "Transferencia",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Owner" : "Dueño",
    "Delete" : "Borrar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Download" : "Descargar",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Comments" : "Comentarios",
    "Save" : "Guardar",
    "Created:" : "Creado:",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "Remove due date" : "Eliminar fecha de expiración",
    "(group)" : "(grupo)",
    "seconds ago" : "hace segundos",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Keyboard shortcut" : "Atajo del teclado",
    "Action" : "Acción",
    "Search" : "Buscar",
    "Archived boards" : "Tableros archivados",
    "Shared with you" : "Compartido con usted",
    "Cancel edit" : "Cancelar edición",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar el tablero",
    "Unarchive board" : "Desarchivar tablero",
    "Archive board" : "Archivar tablero",
    "No notifications" : "No hay notificaciones",
    "Delete board" : "Borrar tableros",
    "Advanced options" : "Opciones avanzadas",
    "Export" : "Exportar",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "Close" : "Cerrar",
    "Due date" : "Fecha de vencimiento",
    "Share" : "Compartir",
    "Personal" : "Personal"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
